.. module:: enaml.core.object

=================
enaml.core.object
=================

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    flag_property


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Object


.. autofunction:: flag_property

.. autoclass:: Object
